wagoe.platform.shell.adapters.database.mysql.connection

MySQL connection settings and JDBC URL.

MySQL connection settings and JDBC URL.
raw docstring

wagoe.platform.shell.adapters.database.mysql.core

MySQL adapter.

LIKE (case-insensitive by MySQL's default collation), booleans as TINYINT(1), and a table name that is not folded — on a case-sensitive filesystem MySQL table names are case-sensitive.

MySQL adapter.

LIKE (case-insensitive by MySQL's default collation), booleans as TINYINT(1),
and a table name that is not folded — on a case-sensitive filesystem MySQL
table names are case-sensitive.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries