Clojure only.

wagoe.platform.shell.adapters.database.mysql.core

MySQL adapter.

LIKE (case-insensitive by MySQL's default collation), booleans as TINYINT(1), and a table name that is not folded — on a case-sensitive filesystem MySQL table names are case-sensitive.

MySQL adapter.

LIKE (case-insensitive by MySQL's default collation), booleans as TINYINT(1),
and a table name that is not folded — on a case-sensitive filesystem MySQL
table names are case-sensitive.
raw docstring

new-adapterclj

(new-adapter)

Create a MySQL adapter.

Create a MySQL adapter.
sourceraw docstring

specclj

What MySQL does differently. See common.adapter for the keys.

What MySQL does differently. See common.adapter for the keys.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries