wagoe.platform.shell.database.validation

Validation functions for database contexts and configurations.

Context validation functions check data structure conformity including protocol satisfaction, which requires access to the DBAdapter protocol from the shell adapters layer.

Validation functions for database contexts and configurations.

Context validation functions check data structure conformity including
protocol satisfaction, which requires access to the DBAdapter protocol
from the shell adapters layer.
raw docstring

adapter-context?clj

(adapter-context? ctx)

Check if value has a valid adapter (subset of db-context).

Checks adapter-specific structure.

Args: ctx: Value to check

Returns: Boolean - true if ctx has valid adapter

Check if value has a valid adapter (subset of db-context).

Checks adapter-specific structure.

Args:
  ctx: Value to check

Returns:
  Boolean - true if ctx has valid adapter
sourceraw docstring

db-context?clj

(db-context? ctx)

Check if value is a valid database context structure.

Checks data structure shape and protocol satisfaction.

Args: ctx: Value to check

Returns: Boolean - true if ctx has correct structure

Check if value is a valid database context structure.

Checks data structure shape and protocol satisfaction.

Args:
  ctx: Value to check

Returns:
  Boolean - true if ctx has correct structure
sourceraw docstring

valid-config-structure?clj

(valid-config-structure? config)

Check if configuration has required structure.

Args: config: Configuration map to check

Returns: Boolean - true if config has :active and :inactive keys

Check if configuration has required structure.

Args:
  config: Configuration map to check

Returns:
  Boolean - true if config has :active and :inactive keys
sourceraw docstring

validate-adapter-configclj

(validate-adapter-config adapter-type config)

Validate adapter configuration based on adapter type.

Dispatches to type-specific validators.

Args: adapter-type: Keyword adapter type (:sqlite, :postgresql, etc.) config: Configuration map

Returns: nil if valid, error message string if invalid

Validate adapter configuration based on adapter type.

Dispatches to type-specific validators.

Args:
  adapter-type: Keyword adapter type (:sqlite, :postgresql, etc.)
  config: Configuration map

Returns:
  nil if valid, error message string if invalid
sourceraw docstring

validate-adapter-contextclj

(validate-adapter-context ctx)

Validate that context has a valid adapter.

Returns context if valid, throws if invalid.

Args: ctx: Context to validate

Returns: ctx if valid

Throws: ExceptionInfo if adapter is invalid

Validate that context has a valid adapter.

Returns context if valid, throws if invalid.

Args:
  ctx: Context to validate

Returns:
  ctx if valid

Throws:
  ExceptionInfo if adapter is invalid
sourceraw docstring

validate-db-contextclj

(validate-db-context ctx)

Validate database context structure.

Returns context if valid, throws if invalid.

Args: ctx: Database context to validate

Returns: ctx if valid

Throws: ExceptionInfo if ctx is invalid

Validate database context structure.

Returns context if valid, throws if invalid.

Args:
  ctx: Database context to validate

Returns:
  ctx if valid

Throws:
  ExceptionInfo if ctx is invalid
sourceraw docstring

validate-h2-configclj

(validate-h2-config config)

Validate H2 adapter configuration.

Args: config: H2 configuration map

Returns: nil if valid, error message string if invalid

Validate H2 adapter configuration.

Args:
  config: H2 configuration map

Returns:
  nil if valid, error message string if invalid
sourceraw docstring

validate-mysql-configclj

(validate-mysql-config config)

Validate MySQL adapter configuration.

Args: config: MySQL configuration map

Returns: nil if valid, error message string if invalid

Validate MySQL adapter configuration.

Args:
  config: MySQL configuration map

Returns:
  nil if valid, error message string if invalid
sourceraw docstring

validate-postgresql-configclj

(validate-postgresql-config config)

Validate PostgreSQL adapter configuration.

Args: config: PostgreSQL configuration map

Returns: nil if valid, error message string if invalid

Validate PostgreSQL adapter configuration.

Args:
  config: PostgreSQL configuration map

Returns:
  nil if valid, error message string if invalid
sourceraw docstring

validate-sqlite-configclj

(validate-sqlite-config config)

Validate SQLite adapter configuration.

Args: config: SQLite configuration map

Returns: nil if valid, error message string if invalid

Validate SQLite adapter configuration.

Args:
  config: SQLite configuration map

Returns:
  nil if valid, error message string if invalid
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries