wagoe.platform.core.http.problem-details

Pure functions for RFC 7807 Problem Details transformations.

All functions are pure data transformations from exceptions to standardized error response structures.

Pure functions for RFC 7807 Problem Details transformations.

All functions are pure data transformations from exceptions to
standardized error response structures.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries