wagoe.platform.ports.http

HTTP routing and server protocols for framework-agnostic route handling.

These protocols define the abstraction for HTTP routing and server operations, allowing the framework to support multiple router implementations (Reitit, Pedestal, etc.) and server implementations (Ring+Jetty, Undertow, etc.) through the Ports & Adapters pattern.

Modules provide normalized route specifications (pure EDN data) which are translated by router adapters into framework-specific route definitions.

HTTP routing and server protocols for framework-agnostic route handling.

These protocols define the abstraction for HTTP routing and server operations,
allowing the framework to support multiple router implementations (Reitit,
Pedestal, etc.) and server implementations (Ring+Jetty, Undertow, etc.)
through the Ports & Adapters pattern.

Modules provide normalized route specifications (pure EDN data) which are
translated by router adapters into framework-specific route definitions.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries