Integrant system lifecycle management for Wagoe application.
This namespace defines init-key and halt-key! multimethods for all system components, providing proper lifecycle management and dependency injection for the entire application.
Components:
Usage: (require '[wagoe.config :as config]) (require '[integrant.core :as ig]) (def cfg (config/ig-config (config/load-config))) (def system (ig/init cfg)) (ig/halt! system)
Integrant system lifecycle management for Wagoe application. This namespace defines init-key and halt-key! multimethods for all system components, providing proper lifecycle management and dependency injection for the entire application. Components: - :wagoe/db-context - Database connection pool and adapter - :wagoe/user-repository - User data persistence - :wagoe/session-repository - Session data persistence - :wagoe/user-service - User business logic orchestration - :wagoe/logging - Structured logging and audit trails - :wagoe/metrics - Application and business metrics collection - :wagoe/error-reporting - Error tracking and alerting - :wagoe/http-handler - HTTP request routing and handling - :wagoe/http-server - Jetty HTTP server Usage: (require '[wagoe.config :as config]) (require '[integrant.core :as ig]) (def cfg (config/ig-config (config/load-config))) (def system (ig/init cfg)) (ig/halt! system)
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |